@@ -12,39 +12,36 @@ class AuthRouter:
     except NameError:
         auth_db = 'default'
 
+    try:
+        token_table = settings.REST_AUTH_TOKEN_TABLE
+    except NameError:
+        token_table = 'AUTHENTICATION_TOKEN'
+
     def db_for_read(self, model, **hints):
-        """
-        Attempts to read auth and contenttypes models go to auth_db.
-        """
+        if model._meta.db_table == self.token_table:
+            return self.auth_db
         if model._meta.app_label in self.route_app_labels:
             return self.auth_db
         return None
 
     def db_for_write(self, model, **hints):
-        """
-        Attempts to write auth and contenttypes models go to auth_db.
-        """
+        if model._meta.db_table == self.token_table:
+            return self.auth_db
         if model._meta.app_label in self.route_app_labels:
             return self.auth_db
         return None
 
     def allow_relation(self, obj1, obj2, **hints):
-        """
-        Allow relations if a model in the auth or contenttypes apps is
-        involved.
-        """
         if (
                 obj1._meta.app_label in self.route_app_labels or
-                obj2._meta.app_label in self.route_app_labels
+                obj2._meta.app_label in self.route_app_labels or
+                obj1._meta.db_table == self.token_table or
+                obj2._meta.db_table == self.token_table
         ):
             return True
         return None
 
     def allow_migrate(self, db, app_label, model_name=None, **hints):
-        """
-        Make sure the auth and contenttypes apps only appear in the
-        auth_db database.
-        """
         if app_label in self.route_app_labels:
             return db == self.auth_db
         return None
